Create Kappa Statistics Matrix

create_kappa_matrix(
  enrichment_res,
  use_description = FALSE,
  use_active_snw_genes = FALSE
)

Arguments

enrichment_res

data frame of pathfindR enrichment results. Must-have columns are 'Term_Description' (if use_description = TRUE) or 'ID' (if use_description = FALSE), 'Down_regulated', and 'Up_regulated'. If use_active_snw_genes = TRUE, 'non_Signif_Snw_Genes' must also be provided.

use_description

Boolean argument to indicate whether term descriptions (in the 'Term_Description' column) should be used. (default = FALSE)

use_active_snw_genes

boolean to indicate whether or not to use non-input active subnetwork genes in the calculation of kappa statistics (default = FALSE, i.e. only use affected genes)

Value

a matrix of kappa statistics between each term in the enrichment results.

Examples

sub_df <- example_pathfindR_output[1:3, ]
create_kappa_matrix(sub_df)
#>            hsa05415   hsa03082   hsa04130
#> hsa05415  1.0000000 -0.6590389 -0.2831858
#> hsa03082 -0.6590389  1.0000000 -0.2360656
#> hsa04130 -0.2831858 -0.2360656  1.0000000