dot-find_components_named: Find the connected components among a set of "on" nodes

.find_components_namedR Documentation

Find the connected components among a set of "on" nodes

Description

Returns one group of node names per connected component of the subgraph induced by on_names (isolated nodes form singleton components).

Usage

.find_components_named(network, on_names)

Arguments

network

A network from build_network().

on_names

Character vector of node names that are switched on.

Value

A list of character vectors, one per component.


pathfindR documentation built on July 2, 2026, 1:06 a.m.