dot-find_subnetworks: Find the scored subnetworks among a set of "on" nodes

.find_subnetworksR Documentation

Find the scored subnetworks among a set of "on" nodes

Description

Find the scored subnetworks among a set of "on" nodes

Usage

.find_subnetworks(network, sc, on_names)

Arguments

network

A network from build_network().

sc

A score context.

on_names

Character vector of node names that are switched on.

Value

A list of subnetwork objects.


pathfindR documentation built on July 2, 2026, 1:06 a.m.