dot-ga_sort_desc: Sort a population from best to worst

.ga_sort_descR Documentation

Sort a population from best to worst

Description

Implements the same ordering as .ga_compare() in a vectorised way: score vectors are laid out in a matrix padded with -Inf, then ordered lexicographically (descending), with the number of subnetworks as a final tie-break so that more subnetworks ranks higher.

Usage

.ga_sort_desc(pop)

Arguments

pop

A list of GA individuals.

Value

The population reordered, best individual first.


pathfindR documentation built on July 2, 2026, 1:06 a.m.