dot-make_subnetwork: Create a subnetwork object from a vector of node names

.make_subnetworkR Documentation

Create a subnetwork object from a vector of node names

Description

Create a subnetwork object from a vector of node names

Usage

.make_subnetwork(sc, nodes)

Arguments

sc

A score context.

nodes

Character vector of node names.

Value

A list with elements nodes, zsum and score.


pathfindR documentation built on July 2, 2026, 1:06 a.m.