dot-parse_experiment: Parse the experiment input into a clean gene / p-value data...

.parse_experimentR Documentation

Parse the experiment input into a clean gene / p-value data frame

Description

Accepts a data frame. If columns named gene and pvalue (case-insensitive) exist they are used, otherwise the first two columns are taken as gene and p-value respectively. Gene names are upper-cased.

Usage

.parse_experiment(experiment)

Arguments

experiment

A data frame of gene / p-value pairs.

Value

A data frame with character column gene and numeric column pvalue.


pathfindR documentation built on July 2, 2026, 1:06 a.m.