dot-sort_subnetworks_desc: Sort a list of subnetwork objects by score, descending

.sort_subnetworks_descR Documentation

Sort a list of subnetwork objects by score, descending

Description

Sort a list of subnetwork objects by score, descending

Usage

.sort_subnetworks_desc(subs)

Arguments

subs

A list of subnetwork objects.

Value

The list reordered so the highest scoring subnetwork is first.


pathfindR documentation built on July 2, 2026, 1:06 a.m.