View source: R/active_snw_filtering.R
| filter_active_subnetworks | R Documentation |
Parse Active Subnetwork Search Output File and Filter the Subnetworks
filter_active_subnetworks(
active_snws,
sig_genes_vec,
score_quan_thr = 0.8,
sig_gene_thr = 0.02
)
active_snws |
active subnetwork search results.
A list containing input |
sig_genes_vec |
vector of significant gene symbols. In the scope of this package, these are the input genes that were used for active subnetwork search |
score_quan_thr |
active subnetwork score quantile threshold. Must be between 0 and 1 or set to -1 for not filtering. (Default = 0.8) |
sig_gene_thr |
threshold for the minimum proportion of significant genes in the subnetwork (Default = 0.02) If the number of genes to use as threshold is calculated to be < 2 (e.g. 50 signif. genes x 0.01 = 0.5), the threshold number is set to 2 |
A list containing subnetworks: a list of of genes in every
active subnetwork that has a score greater than the score_quan_thrth
quantile and that contains at least sig_gene_thr of significant genes
and scores the score of each filtered active subnetwork
See run_pathfindR for the wrapper function of the
pathfindR enrichment workflow
filtered <- filter_active_subnetworks(
active_snws = example_unfiltered_snws,
sig_genes_vec = example_pathfindR_input$Gene.symbol
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.