View source: R/active_snw_search_and_enrichment_wrapper.R
| single_iter_wrapper | R Documentation |
Active Subnetwork Search + Enrichment Analysis Wrapper for a Single Iteration
single_iter_wrapper(
i = NULL,
pin_path,
network,
experiment_df,
score_quan_thr,
sig_gene_thr,
search_method,
verbose,
start_with_all_positives,
gene_init_prob,
sa_initial_temp,
sa_final_temp,
sa_iterations,
ga_population_size,
ga_iterations,
ga_crossover_rate,
ga_mutation_rate,
gr_max_depth,
gr_search_depth,
gr_overlap_threshold,
gr_subnetwork_num,
gset_list,
adj_method,
enrichment_threshold,
list_active_snw_genes
)
i |
current iteration index (default = |
pin_path |
path/to/PIN/file |
network |
Prebuilt network object as returned by |
experiment_df |
input experiment data frame |
score_quan_thr |
active subnetwork score quantile threshold. Must be between 0 and 1 or set to -1 for not filtering. (Default = 0.8) |
sig_gene_thr |
threshold for the minimum proportion of significant genes in the subnetwork (Default = 0.02) If the number of genes to use as threshold is calculated to be < 2 (e.g. 50 signif. genes x 0.01 = 0.5), the threshold number is set to 2 |
search_method |
algorithm to use when performing active subnetwork search. Options are greedy search (GR), simulated annealing (SA) or genetic algorithm (GA) for the search (default = 'GR'). |
verbose |
boolean value indicating whether to print messages (default=FALSE) |
start_with_all_positives |
if TRUE: in GA, adds an individual with all positive nodes. In SA, initializes candidate solution with all positive nodes. (default = FALSE) |
gene_init_prob |
For SA and GA, probability of adding a gene in initial solution (default = 0.1) |
sa_initial_temp |
Initial temperature for SA (default = 1.0) |
sa_final_temp |
Final temperature for SA (default = 0.01) |
sa_iterations |
Iteration number for SA (default = 10000) |
ga_population_size |
Population size for GA (default = 400) |
ga_iterations |
Iteration number for GA (default = 200) |
ga_crossover_rate |
Applies crossover with the given probability in GA (default = 1, i.e. always perform crossover) |
ga_mutation_rate |
For GA, applies mutation with given mutation rate (default = 0, i.e. mutation off) |
gr_max_depth |
Sets max depth in greedy search, 0 for no limit (default = 1) |
gr_search_depth |
Search depth in greedy search (default = 1) |
gr_overlap_threshold |
Overlap threshold for results of greedy search (default = 0.5) |
gr_subnetwork_num |
Number of subnetworks to be presented in the results (default = 1000) |
gset_list |
list for gene sets. |
adj_method |
correction method to be used for adjusting p-values. (default = 'bonferroni') |
enrichment_threshold |
adjusted-p value threshold used when filtering enrichment results (default = 0.05) |
list_active_snw_genes |
boolean value indicating whether or not to report
the non-significant active subnetwork genes for the active subnetwork which was enriched for
the given term with the lowest p value (default = |
Data frame of enrichment results using active subnetwork search results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.