Wrapper for Active Subnetwork Search + Enrichment over Single/Multiple Iteration(s)

active_snw_enrichment_wrapper(
  input_processed,
  pin_path,
  gset_list,
  enrichment_threshold,
  list_active_snw_genes,
  adj_method = "bonferroni",
  search_method = "GR",
  disable_parallel = FALSE,
  start_with_all_positives = FALSE,
  iterations = 10,
  n_processes = NULL,
  score_quan_thr = 0.8,
  sig_gene_thr = 0.02,
  sa_initial_temp = 1,
  sa_final_temp = 0.01,
  sa_iterations = 10000,
  ga_population_size = 400,
  ga_iterations = 200,
  ga_crossover_rate = 1,
  ga_mutation_rate = 0,
  gr_max_depth = 1,
  gr_search_depth = 1,
  gr_overlap_threshold = 0.5,
  gr_subnetwork_num = 1000,
  verbose = FALSE
)

Arguments

input_processed

processed input data frame

pin_path

path/to/PIN/file

gset_list

list for gene sets.

enrichment_threshold

adjusted-p value threshold used when filtering enrichment results (default = 0.05)

list_active_snw_genes

boolean value indicating whether or not to report the non-significant active subnetwork genes for the active subnetwork which was enriched for the given term with the lowest p value (default = FALSE)

adj_method

correction method to be used for adjusting p-values. (default = 'bonferroni')

search_method

algorithm to use when performing active subnetwork search. Options are greedy search (GR), simulated annealing (SA) or genetic algorithm (GA) for the search (default = 'GR').

disable_parallel

boolean to indicate whether to disable parallel runs via foreach (default = FALSE)

start_with_all_positives

if TRUE: in GA, adds an individual with all positive nodes. In SA, initializes candidate solution with all positive nodes. (default = FALSE)

iterations

number of iterations for active subnetwork search and enrichment analyses (Default = 10)

n_processes

optional argument for specifying the number of processes used by foreach. If not specified, the function determines this automatically (Default == NULL. Gets set to 1 for Genetic Algorithm)

score_quan_thr

active subnetwork score quantile threshold. Must be between 0 and 1 or set to -1 for not filtering. (Default = 0.8)

sig_gene_thr

threshold for the minimum proportion of significant genes in the subnetwork (Default = 0.02) If the number of genes to use as threshold is calculated to be < 2 (e.g. 50 signif. genes x 0.01 = 0.5), the threshold number is set to 2

sa_initial_temp

Initial temperature for SA (default = 1.0)

sa_final_temp

Final temperature for SA (default = 0.01)

sa_iterations

Iteration number for SA (default = 10000)

ga_population_size

Population size for GA (default = 400)

ga_iterations

Iteration number for GA (default = 200)

ga_crossover_rate

Applies crossover with the given probability in GA (default = 1, i.e. always perform crossover)

ga_mutation_rate

For GA, applies mutation with given mutation rate (default = 0, i.e. mutation off)

gr_max_depth

Sets max depth in greedy search, 0 for no limit (default = 1)

gr_search_depth

Search depth in greedy search (default = 1)

gr_overlap_threshold

Overlap threshold for results of greedy search (default = 0.5)

gr_subnetwork_num

Number of subnetworks to be presented in the results (default = 1000)

verbose

boolean value indicating whether to print messages (default=FALSE)

Value

Data frame of combined pathfindR enrichment results