Returns one group of node names per connected component of the subgraph induced by on_names (isolated nodes form singleton components).

.find_components_named(network, on_names)

Arguments

network

A network from build_network().

on_names

Character vector of node names that are switched on.

Value

A list of character vectors, one per component.