| .find_components_named | R Documentation |
Returns one group of node names per connected component of the subgraph
induced by on_names (isolated nodes form singleton components).
.find_components_named(network, on_names)
network |
A network from |
on_names |
Character vector of node names that are switched on. |
A list of character vectors, one per component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.