R/active_snw_search_score.R
dot-find_subnetworks.RdFind the scored subnetworks among a set of "on" nodes
.find_subnetworks(network, sc, on_names)A network from build_network().
A score context.
Character vector of node names that are switched on.
A list of subnetwork objects.