| .find_subnetworks | R Documentation |
Find the scored subnetworks among a set of "on" nodes
.find_subnetworks(network, sc, on_names)
network |
A network from |
sc |
A score context. |
on_names |
Character vector of node names that are switched on. |
A list of subnetwork objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.