Implements the same ordering as .ga_compare() in a vectorised way: score vectors are laid out in a matrix padded with -Inf, then ordered lexicographically (descending), with the number of subnetworks as a final tie-break so that more subnetworks ranks higher.

.ga_sort_desc(pop)

Arguments

pop

A list of GA individuals.

Value

The population reordered, best individual first.