| .parse_experiment | R Documentation |
Accepts a data frame. If columns named gene and pvalue
(case-insensitive) exist they are used, otherwise the first two columns are
taken as gene and p-value respectively. Gene names are upper-cased.
.parse_experiment(experiment)
experiment |
A data frame of gene / p-value pairs. |
A data frame with character column gene and numeric column
pvalue.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.