R/active_snw_search_score.R
dot-sort_subnetworks_desc.Rd
Sort a list of subnetwork objects by score, descending
.sort_subnetworks_desc(subs)
A list of subnetwork objects.
The list reordered so the highest scoring subnetwork is first.