| .sort_subnetworks_desc | R Documentation |
Sort a list of subnetwork objects by score, descending
.sort_subnetworks_desc(subs)
subs |
A list of subnetwork objects. |
The list reordered so the highest scoring subnetwork is first.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.