R/active_snw_search_and_enrichment_wrapper.R
single_iter_wrapper.RdActive Subnetwork Search + Enrichment Analysis Wrapper for a Single Iteration
single_iter_wrapper(
i = NULL,
pin_path,
network,
experiment_df,
score_quan_thr,
sig_gene_thr,
search_method,
verbose,
start_with_all_positives,
gene_init_prob,
sa_initial_temp,
sa_final_temp,
sa_iterations,
ga_population_size,
ga_iterations,
ga_crossover_rate,
ga_mutation_rate,
gr_max_depth,
gr_search_depth,
gr_overlap_threshold,
gr_subnetwork_num,
gset_list,
adj_method,
enrichment_threshold,
list_active_snw_genes
)current iteration index (default = NULL)
path/to/PIN/file
Prebuilt network object as returned by build_network(),
built once by active_snw_enrichment_wrapper and passed to every
iteration to avoid redundant PIN file I/O.
input experiment data frame
active subnetwork score quantile threshold. Must be between 0 and 1 or set to -1 for not filtering. (Default = 0.8)
threshold for the minimum proportion of significant genes in the subnetwork (Default = 0.02) If the number of genes to use as threshold is calculated to be < 2 (e.g. 50 signif. genes x 0.01 = 0.5), the threshold number is set to 2
algorithm to use when performing active subnetwork search. Options are greedy search (GR), simulated annealing (SA) or genetic algorithm (GA) for the search (default = 'GR').
boolean value indicating whether to print messages (default=FALSE)
if TRUE: in GA, adds an individual with all positive nodes. In SA, initializes candidate solution with all positive nodes. (default = FALSE)
For SA and GA, probability of adding a gene in initial solution (default = 0.1)
Initial temperature for SA (default = 1.0)
Final temperature for SA (default = 0.01)
Iteration number for SA (default = 10000)
Population size for GA (default = 400)
Iteration number for GA (default = 200)
Applies crossover with the given probability in GA (default = 1, i.e. always perform crossover)
For GA, applies mutation with given mutation rate (default = 0, i.e. mutation off)
Sets max depth in greedy search, 0 for no limit (default = 1)
Search depth in greedy search (default = 1)
Overlap threshold for results of greedy search (default = 0.5)
Number of subnetworks to be presented in the results (default = 1000)
list for gene sets.
correction method to be used for adjusting p-values. (default = 'bonferroni')
adjusted-p value threshold used when filtering enrichment results (default = 0.05)
boolean value indicating whether or not to report
the non-significant active subnetwork genes for the active subnetwork which was enriched for
the given term with the lowest p value (default = FALSE)
Data frame of enrichment results using active subnetwork search results